@@ -1,7 +1,8 @@
 from F import DICT
 from F import LIST
 from F.LOG import Log
-from FCM.MCCore import MCore
+from FCM import MCServers
+from FCM.MCCore import MCCore
 from FCM.Jarticle import JQ, F
 from FCM.FQ import Q
 from bson import ObjectId
@@ -19,10 +20,13 @@ Log = Log("jArticles")
 ARTICLES_COLLECTION = "articles"
 
 """ Master Class to work with Article Collection """
-class jArticles(MCore):
+class jArticles(MCCore):
 
-    def constructor_jarticles_with_host(self, dbUri, dbName):
+    def constructor_jarticles_with_host(self, dbUri=None, dbName=None):
         try:
+            if not dbUri:
+                dbUri = MCServers.MONGO_DATABASE_URI
+                dbName = MCServers.db_name
             # MCDB.GET_SET_CUSTOM_HOST(dbUri, dbName, ARTICLES_COLLECTION)
             self.constructor(dbUri, dbName)
             self.set_ccollection(ARTICLES_COLLECTION)
